@@ -28,7 +28,7 @@ var searchData=
   ['implementation_2eidl_25',['Implementation.idl',['../Implementation_8idl.html',1,'']]],
   ['implementationregistration_2eidl_26',['ImplementationRegistration.idl',['../ImplementationRegistration_8idl.html',1,'']]],
   ['importer_2eidl_27',['Importer.idl',['../Importer_8idl.html',1,'']]],
-  ['importfilter_2eidl_28',['ImportFilter.idl',['../xml_2ImportFilter_8idl.html',1,'(Global Namespace)'],['../document_2ImportFilter_8idl.html',1,'(Global Namespace)']]],
+  ['importfilter_2eidl_28',['ImportFilter.idl',['../document_2ImportFilter_8idl.html',1,'(Global Namespace)'],['../xml_2ImportFilter_8idl.html',1,'(Global Namespace)']]],
   ['incompatibletypesexception_2eidl_29',['IncompatibleTypesException.idl',['../IncompatibleTypesException_8idl.html',1,'']]],
   ['incontentmetadata_2eidl_30',['InContentMetadata.idl',['../InContentMetadata_8idl.html',1,'']]],
   ['incrementdata_2eidl_31',['IncrementData.idl',['../IncrementData_8idl.html',1,'']]],
